@@ -186,6 +186,19 @@ public:
     TS_API
     TsKnotMap GetKnots() const;
 
+    /// \overload
+    /// Get the spline's knots that affect the specified time interval.
+    ///
+    /// Return a TsKnotMap containing the knots that affect the time
+    /// interval. This may include knots outside the time interval if they
+    /// affect the curve inside the time interval. For example, if there
+    /// are knots at times 10, 20, and 30. Calling \c GetKnots with a
+    /// \c timeInteval of [15 .. 25] may return all 3 knots since the
+    /// knots at 10 and 30 may affect the shape of the spline at times
+    /// that are inside the \c timeInterval.
+    TS_API
+    TsKnotMap GetKnots(const GfInterval& timeInterval) const;
+
     /// Retrieves a copy of the knot at the specified time, if one exists.  This
     /// must be an original knot, not a knot that is echoed due to looping.
     /// Returns true on success, false if there is no such knot.
@@ -218,38 +231,83 @@ public:
     /// \name Loop baking
     /// @{
 
-    /// <b>Not yet implemented.</b>
+    /// Bake inner loops in the spline.
+    ///
+    /// Modify the spline by baking out the knots generated by inner looping to
+    /// explicit knots and resetting the looping parameters to default.
     TS_API
-    bool BakeLoops(
-        const GfInterval &interval);
+    bool BakeInnerLoops();
 
-    /// <b>Not yet implemented.</b>
-    //
-    // Result cached
+    /// Return all the knots on the spline, including knots generated by
+    /// inner looping.
+    ///
+    /// These knots can be used to create a new spline that does not use looping
+    /// but has the same shape as this spline. Note that extrapolated knots are
+    /// not included in the result. If you want to include extrapolated knots
+    /// use \c GetKnotsWithLoopsBaked and provide a time interval over which knots
+    /// should be expanded.
     TS_API
-    const TsKnotMap& GetKnotsWithInnerLoopsBaked() const;
+    TsKnotMap GetKnotsWithInnerLoopsBaked() const;
+
+    /// Return baked knots that will replicate this spline over the given time
+    /// interval without any looping.
+    ///
+    /// Return a \c TsKnotMap containing baked knots that will replicate the
+    /// shape of the spline over the time interval without using any looping.
+    /// Both inner and extrapolation loops are included in the returned knots.
+    ///
+    /// If extrapolation loops are in use, the specified \a interval argument,
+    /// \e must specify a finite time interval since extrapolation looping
+    /// extends to infinity and will generate a theoretically infinite number of
+    /// knots. Attempts to bake an infinite number of knots will emit a coding
+    /// error and return an empty \c TsKnotMap.
+    ///
+    /// \note Knots baked from extrapolation loops may include knots that are
+    /// generated from multiple input knots. Knots at loop boundaries get their
+    /// "pre" values from the end of the loop and their "post" values from the
+    /// beginning.
 
-    /// <b>Not yet implemented.</b>
-    //
-    // Bakes inner loops (finite) and extrapolating loops (infinite)
-    // Result cached, but only for last specified interval
     TS_API
-    const TsKnotMap& GetKnotsWithLoopsBaked(
+    TsKnotMap GetKnotsWithLoopsBaked(
         const GfInterval &interval) const;
 
     /// @}
-    /// \name Splitting
+    /// \name Breakdowns
+    ///
+    /// A Breakdown in animation is a pose between the key poses. Breakdown
+    /// applied to a \c TsSpline will insert a TsKnot between existing knots
+    /// with as little disruption as possible to the overall shape of the
+    /// spline.
     /// @{
 
-    /// <b>Not yet implemented.</b>
+    /// Add a knot at the specified time.  The new knot is defined so that the
+    /// shape of the curve is changed as little as possible. If necessary,
+    /// neighboring knots may also be modified.
     ///
-    /// Adds a knot at the specified time.  The new knot is arranged so that the
-    /// shape of the curve is as unchanged as possible.
+    /// There are some situations where a new knot cannot be inserted. For
+    /// example, if there is already a knot at the requested time, or if the
+    /// requested insertion time is in a region of the spline that is looped
+    /// from either extrapolation or inner looping. Use \c CanBreakdown to see
+    /// if a breakdown would succeed.
+    ///
+    /// \return true if a knot was successfully inserted or false if not.
     TS_API
-    bool Split(
+    bool Breakdown(
         TsTime time,
         GfInterval *affectedIntervalOut = nullptr);
 
+    /// Test if a knot could be inserted by \c Breakdown at \c time.
+    ///
+    /// \return true if a knot could be successfully inserted by \c Breakdown
+    /// or false if not. If false is returned and \c reason is not \c nullptr
+    /// then a description of the failure will be stored in \c reason. This is
+    /// the same error or warning message that would have been emitted by
+    /// \c Breakdown if it had failed to insert a knot.
+    TS_API
+    bool CanBreakdown(
+        TsTime time,
+        std::string* reason = nullptr);
+
     /// @}
     /// \name Anti-regression
     ///
