@@ -13,9 +13,6 @@
 #include "pxr/pxr.h"
 #include "pxr/external/boost/python/common.hpp"
 
-#ifndef PXR_USE_INTERNAL_BOOST_PYTHON
-#include <boost/python/detail/is_auto_ptr.hpp>
-#else
 #include <type_traits>
 
 namespace PXR_BOOST_NAMESPACE { namespace python { namespace detail { 
@@ -27,5 +24,4 @@ struct is_auto_ptr : std::false_type
     
 }}} // namespace PXR_BOOST_NAMESPACE::python::detail
 
-#endif // PXR_USE_INTERNAL_BOOST_PYTHON
 #endif // PXR_EXTERNAL_BOOST_PYTHON_DETAIL_IS_AUTO_PTR_HPP
