@@ -9,6 +9,7 @@
 
 #include "pxr/imaging/geomUtil/api.h"
 #include "pxr/imaging/geomUtil/meshGeneratorBase.h"
+#include "pxr/imaging/geomUtil/tokens.h"
 
 #include "pxr/pxr.h"
 
@@ -17,17 +18,19 @@ PXR_NAMESPACE_OPEN_SCOPE
 class GfMatrix4d;
 class PxOsdMeshTopology;
 
-/// This class provides an implementation for generating topology and point
-/// positions on a cone of a given radius and height.  The cone is made up of
-/// circular cross-sections in the XY plane and is centered at the origin.  Each
-/// cross-section has numRadial segments.  The height is aligned with the Z
-/// axis, with the base of the object at Z = -h/2 and apex at Z = h/2.
+/// This class provides an implementation for generating topology, point
+/// positions and surface normals on a cone of a given radius and height. The
+/// cone is made up of circular cross-sections in the XY plane and is centered
+/// at the origin. Each cross-section has numRadial segments.  The height is
+/// aligned with the Z axis, with the base of the object at Z = -h/2 and apex
+/// at Z = h/2.
 ///
-/// An optional transform may be provided to GeneratePoints to orient the
-/// cone as necessary (e.g., whose height is along the Y axis) .
+/// An optional transform may be provided to GeneratePoints and GenerateNormals
+/// to orient the cone as necessary (e.g., whose height is aligned with the
+/// Y axis).
 ///
 /// An additional overload of GeneratePoints is provided to specify the sweep
-/// angle for the cone about the +Z axis.  When the sweep is less than 360 
+/// angle for the cone about the +Z axis.  When the sweep is less than 360
 /// degrees, the generated geometry is not closed.
 ///
 /// Usage:
@@ -43,6 +46,14 @@ class PxOsdMeshTopology;
 /// GeomUtilConeMeshGenerator::GeneratePoints(
 ///     points.begin(), numRadial, radius, height);
 ///
+/// const size_t numNormals =
+///     GeomUtilConeMeshGenerator::ComputeNumNormals(numRadial);
+///
+/// MyPointContainer<GfVec3f> normals(numNormals);
+///
+/// GeomUtilConeMeshGenerator::GenerateNormals(
+///     normals.begin(), numRadial, radius, height);
+///
 /// \endcode
 ///
 class GeomUtilConeMeshGenerator final
@@ -56,6 +67,20 @@ public:
         const size_t numRadial,
         const bool closedSweep = true);
 
+    static size_t ComputeNumNormals(
+        const size_t numRadial,
+        const bool closedSweep = true)
+    {
+        // Normals are per point.
+        return ComputeNumPoints(numRadial, closedSweep);
+    }
+
+    static TfToken GetNormalsInterpolation()
+    {
+        // Normals are per point.
+        return GeomUtilInterpolationTokens->vertex;
+    }
+
     GEOMUTIL_API
     static PxOsdMeshTopology GenerateTopology(
         const size_t numRadial,
@@ -98,8 +123,45 @@ public:
 
     using GeomUtilMeshGeneratorBase::GeneratePoints;
 
+    template<typename PointIterType,
+             typename ScalarType,
+             typename Enabled =
+                typename _EnableIfGfVec3Iterator<PointIterType>::type>
+    static void GenerateNormals(
+        PointIterType iter,
+        const size_t numRadial,
+        const ScalarType radius,
+        const ScalarType height,
+        const GfMatrix4d* framePtr = nullptr)
+    {
+        constexpr ScalarType sweep = 360;
+        GenerateNormals(iter, numRadial, radius, height, sweep, framePtr);
+    }
+
+    template<typename PointIterType,
+             typename ScalarType,
+             typename Enabled =
+                typename _EnableIfGfVec3Iterator<PointIterType>::type>
+    static void GenerateNormals(
+        PointIterType iter,
+        const size_t numRadial,
+        const ScalarType radius,
+        const ScalarType height,
+        const ScalarType sweepDegrees,
+        const GfMatrix4d* framePtr = nullptr)
+    {
+        using PointType =
+            typename std::iterator_traits<PointIterType>::value_type;
+
+        _GenerateNormalsImpl(numRadial, radius, height, sweepDegrees,
+            framePtr ? _PointWriter<PointType>(iter, framePtr)
+                     : _PointWriter<PointType>(iter));
+    }
+
+    using GeomUtilMeshGeneratorBase::GenerateNormals;
+
 private:
-    
+
     template<typename PointType>
     static void _GeneratePointsImpl(
         const size_t numRadial,
@@ -107,6 +169,14 @@ private:
         const typename PointType::ScalarType height,
         const typename PointType::ScalarType sweepDegrees,
         const _PointWriter<PointType>& ptWriter);
+
+    template<typename PointType>
+    static void _GenerateNormalsImpl(
+        const size_t numRadial,
+        const typename PointType::ScalarType radius,
+        const typename PointType::ScalarType height,
+        const typename PointType::ScalarType sweepDegrees,
+        const _PointWriter<PointType>& ptWriter);
 };
 
 PXR_NAMESPACE_CLOSE_SCOPE
