@@ -49,6 +49,11 @@ public:
         return _materialPrimPath;
     }
 
+    HD_API
+    TfTokenVector GetMaterialConfigKeys() const override;
+    HD_API
+    VtValue GetMaterialConfigValue(const TfToken& key) const override;
+
     HD_API
     std::string GetModelAssetName() const override;
 
@@ -90,11 +95,20 @@ public:
     HD_API
     void DeleteNode(const TfToken &nodeName) override;
 
+    /// Set the nodeType for the shader node with the given \p nodeName. 
+    /// If \p nodeType is empty then the nodeType attribute will be removed
+    /// from the node's dataSource.
     HD_API
     void SetNodeType(
         const TfToken &nodeName,
         const TfToken &nodeType) override;
 
+    HD_API
+    void SetNodeTypeInfoValue(
+        const TfToken &nodeName,
+        const TfToken &key,
+        const VtValue &value) override;
+
     HD_API
     void SetNodeParameterValue(
         const TfToken &nodeName,
@@ -143,6 +157,15 @@ public:
     HdContainerDataSourceHandle Finish();
 
 private:
+
+    /// Return the nodeTypeInfo dataSource, if it exists, for the specified 
+    /// \p nodeName. Does NOT take into account any overrides of the nodeType 
+    /// data that may have been authored by SetNodeTypeInfoValue().
+    HdContainerDataSourceHandle _GetOriginalNodeTypeInfo(
+            const TfToken& nodeName) const;
+
+    /// Return the nodeTypeInfo dataSource for the supplied \p nodeName,  
+    /// taking into account any overrides that may have been authored.
     HdContainerDataSourceHandle _GetNodeTypeInfo(
             const TfToken& nodeName) const;
 
@@ -150,6 +173,13 @@ private:
         std::unordered_map<HdDataSourceLocator, HdDataSourceBaseHandle,
             TfHash>;
 
+    using _HdContainerDataSourceEditorSharedPtr = 
+        std::shared_ptr<class HdContainerDataSourceEditor>;
+
+    using _NodeTypeInfoMap = 
+        std::unordered_map<TfToken, _HdContainerDataSourceEditorSharedPtr, 
+            TfToken::HashFunctor>;
+
     using _TokenSet = std::unordered_set<TfToken, TfHash>;
 
     void _SetOverride(
@@ -159,6 +189,7 @@ private:
     SdfPath _materialPrimPath;
     mutable HdMaterialNetworkSchema _networkSchema;
     HdContainerDataSourceEditor _networkEditor;
+    _NodeTypeInfoMap _nodeTypeInfoOverrides;
     HdContainerDataSourceHandle _primContainer;
     _OverrideMap _existingOverrides;
     _TokenSet _overriddenNodes;
