@@ -64,25 +64,26 @@ using HgiBits = uint32_t;
 ///
 enum HgiDeviceCapabilitiesBits : HgiBits
 {
-    HgiDeviceCapabilitiesBitsPresentation            = 1 << 0,
-    HgiDeviceCapabilitiesBitsBindlessBuffers         = 1 << 1,
-    HgiDeviceCapabilitiesBitsConcurrentDispatch      = 1 << 2,
-    HgiDeviceCapabilitiesBitsUnifiedMemory           = 1 << 3,
-    HgiDeviceCapabilitiesBitsBuiltinBarycentrics     = 1 << 4,
-    HgiDeviceCapabilitiesBitsShaderDrawParameters    = 1 << 5,
-    HgiDeviceCapabilitiesBitsMultiDrawIndirect       = 1 << 6,
-    HgiDeviceCapabilitiesBitsBindlessTextures        = 1 << 7,
-    HgiDeviceCapabilitiesBitsShaderDoublePrecision   = 1 << 8,
-    HgiDeviceCapabilitiesBitsDepthRangeMinusOnetoOne = 1 << 9,
-    HgiDeviceCapabilitiesBitsCppShaderPadding        = 1 << 10,
-    HgiDeviceCapabilitiesBitsConservativeRaster      = 1 << 11,
-    HgiDeviceCapabilitiesBitsStencilReadback         = 1 << 12,
-    HgiDeviceCapabilitiesBitsCustomDepthRange        = 1 << 13,
-    HgiDeviceCapabilitiesBitsMetalTessellation       = 1 << 14,
-    HgiDeviceCapabilitiesBitsBasePrimitiveOffset     = 1 << 15,
-    HgiDeviceCapabilitiesBitsPrimitiveIdEmulation    = 1 << 16,
-    HgiDeviceCapabilitiesBitsIndirectCommandBuffers  = 1 << 17,
-    HgiDeviceCapabilitiesBitsRoundPoints             = 1 << 18,
+    HgiDeviceCapabilitiesBitsPresentation             = 1 << 0,
+    HgiDeviceCapabilitiesBitsBindlessBuffers          = 1 << 1,
+    HgiDeviceCapabilitiesBitsConcurrentDispatch       = 1 << 2,
+    HgiDeviceCapabilitiesBitsUnifiedMemory            = 1 << 3,
+    HgiDeviceCapabilitiesBitsBuiltinBarycentrics      = 1 << 4,
+    HgiDeviceCapabilitiesBitsShaderDrawParameters     = 1 << 5,
+    HgiDeviceCapabilitiesBitsMultiDrawIndirect        = 1 << 6,
+    HgiDeviceCapabilitiesBitsBindlessTextures         = 1 << 7,
+    HgiDeviceCapabilitiesBitsShaderDoublePrecision    = 1 << 8,
+    HgiDeviceCapabilitiesBitsDepthRangeMinusOnetoOne  = 1 << 9,
+    HgiDeviceCapabilitiesBitsCppShaderPadding         = 1 << 10,
+    HgiDeviceCapabilitiesBitsConservativeRaster       = 1 << 11,
+    HgiDeviceCapabilitiesBitsStencilReadback          = 1 << 12,
+    HgiDeviceCapabilitiesBitsCustomDepthRange         = 1 << 13,
+    HgiDeviceCapabilitiesBitsMetalTessellation        = 1 << 14,
+    HgiDeviceCapabilitiesBitsBasePrimitiveOffset      = 1 << 15,
+    HgiDeviceCapabilitiesBitsPrimitiveIdEmulation     = 1 << 16,
+    HgiDeviceCapabilitiesBitsIndirectCommandBuffers   = 1 << 17,
+    HgiDeviceCapabilitiesBitsRoundPoints              = 1 << 18,
+    HgiDeviceCapabilitiesBitsSingleSlotResourceArrays = 1 << 19,
 };
 
 using HgiDeviceCapabilities = HgiBits;
@@ -98,6 +99,8 @@ using HgiDeviceCapabilities = HgiBits;
 ///   A two-dimensional texture.</li>
 /// <li>HgiTextureType3D:
 ///   A three-dimensional texture.</li>
+/// <li>HgiTextureTypeCubemap:
+///   A cubemap texture.</li>
 /// <li>HgiTextureType1DArray:
 ///   An array of one-dimensional textures.</li>
 /// <li>HgiTextureType2DArray:
@@ -109,6 +112,7 @@ enum HgiTextureType
     HgiTextureType1D = 0,
     HgiTextureType2D,
     HgiTextureType3D,
+    HgiTextureTypeCubemap,
     HgiTextureType1DArray,
     HgiTextureType2DArray,
 
@@ -789,13 +793,16 @@ enum HgiStorageType
 ///   Indicates a shadow texture.</li>
 /// <li>HgiShaderTextureTypeArrayTexture:
 ///   Indicates an array texture.</li>
+/// <li>HgiShaderTextureTypeCubemapTexture:
+///   Indicates a cubemap texture.</li>
 /// </ul>
 ///
 enum HgiShaderTextureType
 {
     HgiShaderTextureTypeTexture = 0,
     HgiShaderTextureTypeShadowTexture,
-    HgiShaderTextureTypeArrayTexture
+    HgiShaderTextureTypeArrayTexture,
+    HgiShaderTextureTypeCubemapTexture
 };
 
 /// \enum HgiComputeDispatch
