@@ -18,7 +18,7 @@
 #include "pxr/usd/usdShade/input.h"
 #include "pxr/usd/usdShade/output.h"
 #include "pxr/usd/usdShade/tokens.h"
-#include "pxr/usd/ndr/declare.h"
+#include "pxr/usd/sdr/declare.h"
 #include "pxr/usd/sdr/shaderNode.h"
 
 #include "pxr/base/vt/value.h"
@@ -361,15 +361,15 @@ public:
     /// We expect the keys in sdrMetadata to correspond to the keys 
     /// in \ref SdrNodeMetadata. However, this is not strictly enforced in the 
     /// API. The only allowed value type in the "sdrMetadata" dictionary is a 
-    /// std::string since it needs to be converted into a NdrTokenMap, which Sdr
+    /// std::string since it needs to be converted into a SdrTokenMap, which Sdr
     /// will parse using the utilities available in \ref SdrMetadataHelpers.
     /// 
     /// @{
 
     /// Returns this shader's composed "sdrMetadata" dictionary as a 
-    /// NdrTokenMap.
+    /// SdrTokenMap.
     USDSHADE_API
-    NdrTokenMap GetSdrMetadata() const;
+    SdrTokenMap GetSdrMetadata() const;
     
     /// Returns the value corresponding to \p key in the composed 
     /// <b>sdrMetadata</b> dictionary.
@@ -379,7 +379,7 @@ public:
     /// Authors the given \p sdrMetadata on this shader at the current 
     /// EditTarget.
     USDSHADE_API
-    void SetSdrMetadata(const NdrTokenMap &sdrMetadata) const;
+    void SetSdrMetadata(const SdrTokenMap &sdrMetadata) const;
 
     /// Sets the value corresponding to \p key to the given string \p value, in 
     /// the shader's "sdrMetadata" dictionary at the current EditTarget.
