@@ -17,7 +17,7 @@ PXR_NAMESPACE_OPEN_SCOPE
 #define USDIMAGING_TOKENS   \
     ((collectionLightLink, "collection:lightLink")) \
     ((collectionShadowLink, "collection:shadowLink")) \
-    ((infoSource, "info:source")) \
+    ((configPrefix, "config:")) \
     (faceIndexPrimvar)      \
     (faceOffsetPrimvar)     \
     ((primvarsNormals, "primvars:normals")) \
