@@ -15,7 +15,7 @@
 #   define USDPHYSICSVALIDATORS_API_TEMPLATE_STRUCT(...)
 #   define USDPHYSICSVALIDATORS_API_LOCAL
 #else
-#   if defined(USDPHYSICSVALIDATORS_API_EXPORTS)
+#   if defined(USDPHYSICSVALIDATORS_EXPORTS)
 #       define USDPHYSICSVALIDATORS_API ARCH_EXPORT
 #       define USDPHYSICSVALIDATORS_API_TEMPLATE_CLASS(...)                      \
            ARCH_EXPORT_TEMPLATE(class, __VA_ARGS__)
