@@ -11,6 +11,7 @@
 #include "pxr/base/tf/singleton.h"
 #include "pxr/usdValidation/usdValidation/api.h"
 #include "pxr/usdValidation/usdValidation/validator.h"
+#include "pxr/usdValidation/usdValidation/fixer.h"
 
 #include <memory>
 #include <shared_mutex>
@@ -112,19 +113,20 @@ PXR_NAMESPACE_OPEN_SCOPE
 ///
 /// Clients can also register validators by explicitly providing
 /// UsdValidationValidatorMetadata, instead of relying on plugInfo.json for the
-/// same. Though its recommended to use appropriate APIs when validator metadata
+/// same. Though it's recommended to use appropriate APIs when validator metadata
 /// is being provided in the plugInfo.json.
 ///
-/// Example of validator registration by explicitly providing metadata, when its
+/// Example of validator registration by explicitly providing metadata, when it's
 /// not available in the plugInfo.json:
 ///
 /// ```cpp
 /// {
 ///     UsdValidationRegistry& registry = UsdValidationRegistry::GetInstance();
 ///     const UsdValidationValidatorMetadata &metadata =
-///     GetMetadataToBeRegistered(); const UsdValidateLayerTaskFn &layerTask =
-///     GetLayerTaskForValidator(); registry.RegisterValidator(metadata,
-///     layerTask);
+///         GetMetadataToBeRegistered();
+///     const UsdValidateLayerTaskFn &layerTask =
+///         GetLayerTaskForValidator();
+///     registry.RegisterValidator(metadata, layerTask);
 /// }
 /// ```
 ///
@@ -145,8 +147,21 @@ PXR_NAMESPACE_OPEN_SCOPE
 /// the registry) or retrieving previously registered validator are designed to
 /// be thread-safe.
 ///
+/// Validators may also have a number of fixers associated with them, which
+/// can provide potential fixes for various validation errors associated with a
+/// validation task. Fixers can be retrieved from the UsdValidationValidator or
+/// the UsdValidationError itself. Note that UsdValidationRegistry does not
+/// manage fixers directly, and these are held by respective
+/// UsdValidationValidator(s). It's the responsibility of the client to retrieve
+/// appropriate fixers for a given error and apply them, on a provided
+/// UsdEditTarget. UsdValidationErrorSite(s) associated with a validation error
+/// provide the context of the error, which may be used while applying a fix on
+/// a UsdEditTarget, or a stronger layer can be used as an edit target to apply
+/// the fix.
+///
 /// \sa UsdValidationValidator
 /// \sa UsdValidationValidatorSuite
+/// \sa UsdValidationFixer
 class UsdValidationRegistry
 {
     UsdValidationRegistry(const UsdValidationRegistry &) = delete;
@@ -173,10 +188,13 @@ public:
     /// Also note any other failure to register a validator results in a coding
     /// error.
     ///
+    /// \p fixers can be provided to associate fixers with the validator.
+    ///
     /// \sa HasValidator
     USDVALIDATION_API
     void RegisterPluginValidator(const TfToken &validatorName,
-                                 const UsdValidateLayerTaskFn &layerTaskFn);
+                                 const UsdValidateLayerTaskFn &layerTaskFn,
+                                 std::vector<UsdValidationFixer> fixers = {});
 
     /// Register UsdValidationValidator defined in a plugin using \p
     /// validatorName and \p stageTaskFn with the UsdValidationRegistry.
@@ -192,10 +210,13 @@ public:
     /// Also note any other failure to register a validator results in a coding
     /// error.
     ///
+    /// \p fixers can be provided to associate fixers with the validator.
+    ///
     /// \sa HasValidator
     USDVALIDATION_API
     void RegisterPluginValidator(const TfToken &validatorName,
-                                 const UsdValidateStageTaskFn &stageTaskFn);
+                                 const UsdValidateStageTaskFn &stageTaskFn,
+                                 std::vector<UsdValidationFixer> fixers = {});
 
     /// Register UsdValidationValidator defined in a plugin using \p
     /// validatorName and \p primTaskFn with the UsdValidationRegistry.
@@ -211,10 +232,13 @@ public:
     /// Also note any other failure to register a validator results in a coding
     /// error.
     ///
+    /// \p fixers can be provided to associate fixers with the validator.
+    ///
     /// \sa HasValidator
     USDVALIDATION_API
     void RegisterPluginValidator(const TfToken &validatorName,
-                                 const UsdValidatePrimTaskFn &primTaskFn);
+                                 const UsdValidatePrimTaskFn &primTaskFn,
+                                 std::vector<UsdValidationFixer> fixers = {});
 
     /// Register UsdValidationValidator using \p metadata and \p layerTaskFn
     /// with the UsdValidationRegistry.
@@ -231,10 +255,13 @@ public:
     /// Also note any other failure to register a validator results in a coding
     /// error.
     ///
+    /// \p fixers can be provided to associate fixers with the validator.
+    ///
     /// \sa HasValidator
     USDVALIDATION_API
     void RegisterValidator(const UsdValidationValidatorMetadata &metadata,
-                           const UsdValidateLayerTaskFn &layerTaskFn);
+                           const UsdValidateLayerTaskFn &layerTaskFn,
+                           std::vector<UsdValidationFixer> fixers = {});
 
     /// Register UsdValidationValidator using \p metadata and \p stageTaskFn
     /// with the UsdValidationRegistry.
@@ -251,10 +278,13 @@ public:
     /// Also note any other failure to register a validator results in a coding
     /// error.
     ///
+    /// \p fixers can be provided to associate fixers with the validator.
+    ///
     /// \sa HasValidator
     USDVALIDATION_API
     void RegisterValidator(const UsdValidationValidatorMetadata &metadata,
-                           const UsdValidateStageTaskFn &stageTaskFn);
+                           const UsdValidateStageTaskFn &stageTaskFn,
+                           std::vector<UsdValidationFixer> fixers = {});
 
     /// Register UsdValidationValidator using \p metadata and \p primTaskFn
     /// with the UsdValidationRegistry.
@@ -271,10 +301,13 @@ public:
     /// Also note any other failure to register a validator results in a coding
     /// error.
     ///
+    /// \p fixers can be provided to associate fixers with the validator.
+    ///
     /// \sa HasValidator
     USDVALIDATION_API
     void RegisterValidator(const UsdValidationValidatorMetadata &metadata,
-                           const UsdValidatePrimTaskFn &primTaskFn);
+                           const UsdValidatePrimTaskFn &primTaskFn,
+                           std::vector<UsdValidationFixer> fixers = {});
 
     /// Register UsdValidationValidatorSuite defined in a plugin using
     /// \p validatorSuiteName and \p containedValidators with the
@@ -511,13 +544,15 @@ private:
     // UsdValidateStageTaskFn or UsdValidatePrimTaskFn.
     template <typename ValidateTaskFn>
     void _RegisterPluginValidator(const TfToken &validatorName,
-                                  const ValidateTaskFn &taskFn);
+                                  const ValidateTaskFn &taskFn,
+                                  std::vector<UsdValidationFixer> fixers);
 
     // Overloaded templated _RegisterValidator, where metadata is explicitly
     // provided.
     template <typename ValidateTaskFn>
     void _RegisterValidator(const UsdValidationValidatorMetadata &metadata,
                             const ValidateTaskFn &taskFn,
+                            std::vector<UsdValidationFixer> fixers,
                             bool addMetadata = true);
 
     void _RegisterValidatorSuite(
